package com.ruoyi.system.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.ruoyi.system.mapper.RiderPositionMapper;
import com.ruoyi.system.domain.RiderPosition;
import com.ruoyi.system.service.IRiderPositionService;

/**
 * RiderPositionService业务层处理
 * 
 * @author ruoyi
 * @date 2023-07-31
 */
@Service
public class RiderPositionServiceImpl extends ServiceImpl<BaseMapper<RiderPosition>,RiderPosition> implements IRiderPositionService
{
    @Autowired
    private RiderPositionMapper riderPositionMapper;

    /**
     * 查询RiderPosition
     * 
     * @param id RiderPosition主键
     * @return RiderPosition
     */
    @Override
    public RiderPosition selectRiderPositionById(Long id)
    {
        return riderPositionMapper.selectRiderPositionById(id);
    }

    /**
     * 查询RiderPosition列表
     * 
     * @param riderPosition RiderPosition
     * @return RiderPosition
     */
    @Override
    public List<RiderPosition> selectRiderPositionList(RiderPosition riderPosition)
    {
        return riderPositionMapper.selectRiderPositionList(riderPosition);
    }

    /**
     * 新增RiderPosition
     * 
     * @param riderPosition RiderPosition
     * @return 结果
     */
    @Override
    public int insertRiderPosition(RiderPosition riderPosition)
    {
        return riderPositionMapper.insertRiderPosition(riderPosition);
    }

    /**
     * 修改RiderPosition
     * 
     * @param riderPosition RiderPosition
     * @return 结果
     */
    @Override
    public int updateRiderPosition(RiderPosition riderPosition)
    {
        return riderPositionMapper.updateRiderPosition(riderPosition);
    }

    /**
     * 批量删除RiderPosition
     * 
     * @param ids 需要删除的RiderPosition主键
     * @return 结果
     */
    @Override
    public int deleteRiderPositionByIds(Long[] ids)
    {
        return riderPositionMapper.deleteRiderPositionByIds(ids);
    }

    /**
     * 删除RiderPosition信息
     * 
     * @param id RiderPosition主键
     * @return 结果
     */
    @Override
    public int deleteRiderPositionById(Long id)
    {
        return riderPositionMapper.deleteRiderPositionById(id);
    }
}
